These method functions extract the estimated model coefficients and their (co)variance matrix from a DLNM from objects of class "crosspred" and "crossreduce".

# S3 method for class 'crosspred'
coef(object, ...)

# S3 method for class 'crosspred'
vcov(object, ...)

# S3 method for class 'crossreduce'
coef(object, ...)

# S3 method for class 'crossreduce'
vcov(object, ...)

Arguments

object

an object of class "crosspred" or "crossreduce".

...

further arguments passed to or from other methods.

Author

Antonio Gasparrini <antonio.gasparrini@lshtm.ac.uk>

See also

See dlnm-package for an introduction to the package and for links to package vignettes providing more detailed information.